@@ -1,10 +1,9 @@
 package Catalyst::Plugin::AutoCRUD::Controller::DisplayEngine::Skinny;
-{
-  $Catalyst::Plugin::AutoCRUD::Controller::DisplayEngine::Skinny::VERSION = '2.142820';
-}
+
+
 
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 
 use base 'Catalyst::Controller';
 
