@@ -1,10 +1,9 @@
 package Catalyst::Plugin::AutoCRUD::Model::StorageEngine::DBIC;
-{
-  $Catalyst::Plugin::AutoCRUD::Model::StorageEngine::DBIC::VERSION = '2.142820';
-}
+
+
 
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 
 use base 'Catalyst::Model';
 
