@@ -1,10 +1,9 @@
 package Catalyst::Plugin::AutoCRUD::View::JSON;
-{
-  $Catalyst::Plugin::AutoCRUD::View::JSON::VERSION = '2.142820';
-}
+
+
 
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 
 use base 'Catalyst::View::JSON';
 
