@@ -1,10 +1,9 @@
 package Catalyst::Plugin::AutoCRUD::View::TT;
-{
-  $Catalyst::Plugin::AutoCRUD::View::TT::VERSION = '2.142820';
-}
+
+
 
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 
 use base 'Catalyst::View::TT';
 use File::Basename;
