@@ -1,10 +1,9 @@
 package SQL::Translator::AutoCRUD::Utils;
-{
-  $SQL::Translator::AutoCRUD::Utils::VERSION = '2.142820';
-}
+
+
 
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 
 our @EXPORT;
 BEGIN {
