@@ -1,10 +1,9 @@
 package SQL::Translator::Filter::AutoCRUD::CatalystModel;
-{
-  $SQL::Translator::Filter::AutoCRUD::CatalystModel::VERSION = '2.142820';
-}
+
+
 
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 
 sub filter {
     my ($schema, @args) = @_;
