@@ -1,10 +1,9 @@
 package SQL::Translator::Filter::AutoCRUD::ColumnsAndPKs;
-{
-  $SQL::Translator::Filter::AutoCRUD::ColumnsAndPKs::VERSION = '2.142820';
-}
+
+
 
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 
 # PK can be FK so need to unique fields
 use List::MoreUtils 'uniq';
