@@ -1,10 +1,9 @@
 package SQL::Translator::Filter::AutoCRUD::DisplayName;
-{
-  $SQL::Translator::Filter::AutoCRUD::DisplayName::VERSION = '2.142820';
-}
+
+
 
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 
 use Scalar::Util 'blessed';
 use SQL::Translator::AutoCRUD::Utils;
