@@ -1,7 +1,6 @@
 package SQL::Translator::Filter::AutoCRUD::ExtJSxType;
-{
-  $SQL::Translator::Filter::AutoCRUD::ExtJSxType::VERSION = '2.143070';
-}
+
+
 
 use strict;
 use warnings;
@@ -10,9 +9,12 @@ my %xtype_for = (
     boolean => 'checkbox',
 );
 
-$xtype_for{$_} = 'numberfield' for (
+$xtype_for{$_} = 'textfield' for (
     'bigint',
     'bigserial',
+);
+
+$xtype_for{$_} = 'numberfield' for (
     'dec',
     'decimal',
     'double precision',
