@@ -1,14 +1,13 @@
 package SQL::Translator::Filter::AutoCRUD::StorageEngine::DBIC::AccessorDisplayName;
-{
-  $SQL::Translator::Filter::AutoCRUD::StorageEngine::DBIC::AccessorDisplayName::VERSION = '2.142820';
-}
+
+
 
 # Although AutoCRUD is "safe" for columns of any weird name you like,
 # if the user has specified a DBIC Column accessor then it's nice
 # to show that as the display name instead of the column's native name.
 
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 
 use SQL::Translator::AutoCRUD::Utils;
 
