@@ -1,7 +1,6 @@
 package SQL::Translator::Filter::AutoCRUD::StorageEngine::DBIC::DynamicDefault;
-{
-  $SQL::Translator::Filter::AutoCRUD::StorageEngine::DBIC::DynamicDefault::VERSION = '2.142820';
-}
+
+
 
 # DBIx:Class extensions such as DBIx::Class::TimeStamp or
 # DBIx::Class::DynamicDefault will set column values on create/update.
@@ -9,7 +8,7 @@ package SQL::Translator::Filter::AutoCRUD::StorageEngine::DBIC::DynamicDefault;
 # ignores the fields for create and update.
 
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 
 use SQL::Translator::AutoCRUD::Utils;
 
