@@ -1,14 +1,13 @@
 package SQL::Translator::Filter::AutoCRUD::StorageEngine::DBIC::ProxyColumns;
-{
-  $SQL::Translator::Filter::AutoCRUD::StorageEngine::DBIC::ProxyColumns::VERSION = '2.142820';
-}
+
+
 
 # The DBIC Relation proxy atribute can be used to import accessors from
 # related tables. This filter parses the attribute and installs columns
 # which AutoCRUD will display.
 
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 
 use SQL::Translator::AutoCRUD::Utils;
 
