@@ -1,7 +1,6 @@
 package SQL::Translator::Filter::AutoCRUD::StorageEngine::DBIC::ViewsAsTables;
-{
-  $SQL::Translator::Filter::AutoCRUD::StorageEngine::DBIC::ViewsAsTables::VERSION = '2.142820';
-}
+
+
 
 # SQLT doesn't provide for proper Field objects in Views
 # instead, there is simply an ordered list of field names.
@@ -11,7 +10,7 @@ package SQL::Translator::Filter::AutoCRUD::StorageEngine::DBIC::ViewsAsTables;
 # run very early on in the Filter list, if not first.
 
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 
 use SQL::Translator::AutoCRUD::Utils;
 
