@@ -1,7 +1,7 @@
 package TestApp::View::TT;
 
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 
 use base 'Catalyst::View::TT';
 use File::Basename;
